@@ -1,11 +1,10 @@
 package DateTime::Duration;
-BEGIN {
-  $DateTime::Duration::VERSION = '0.60';
-}
 
 use strict;
 use warnings;
 
+our $VERSION = '0.61';
+
 use Carp ();
 use DateTime;
 use DateTime::Helpers;
@@ -318,7 +317,7 @@ DateTime::Duration - Duration objects for date math
 
 =head1 VERSION
 
-version 0.60
+version 0.62
 
 =head1 SYNOPSIS
 
@@ -330,7 +329,7 @@ version 0.60
                                 days    => 1,
                                 hours   => 6,
                                 minutes => 15,
-                                seconds => 45, 
+                                seconds => 45,
                                 nanoseconds => 12000 );
 
   # Convert to different units
@@ -468,9 +467,9 @@ conversions possible are:
 
 =back
 
-For the explanation of why this happens, please see the L<How Date
-Math is Done|DateTime/"How Date Math is Done"> section of the
-DateTime.pm documentation
+For the explanation of why this happens, please see the L<How Datetime Math
+Works|DateTime/"How DateTime Math Works"> section of the DateTime.pm
+documentation
 
 Note that the numbers returned by this method may not match the values
 given to the constructor.
